changeset 21454:1361a790bca8

(relocate_fd): Avoid `min'/`max' as variable names.
author Karl Heuer <kwzh@gnu.org>
date Thu, 09 Apr 1998 17:47:17 +0000
parents f23a3354d0ad
children 4a457fda49b5
files src/callproc.c
diffstat 1 files changed, 5 insertions(+), 5 deletions(-) [+]
line wrap: on
line diff
--- a/src/callproc.c	Thu Apr 09 17:21:02 1998 +0000
+++ b/src/callproc.c	Thu Apr 09 17:47:17 1998 +0000
@@ -1128,13 +1128,13 @@
 #endif /* not MSDOS */
 }
 
 /* Move the file descriptor FD so that its number is not less than MIN.
    If the file descriptor is moved at all, the original is freed.  */
 int
-relocate_fd (fd, min)
-     int fd, min;
+relocate_fd (fd, minfd)
+     int fd, minfd;
 {
-  if (fd >= min)
+  if (fd >= minfd)
     return fd;
   else
     {
@@ -1151,7 +1151,7 @@
 	}
       /* Note that we hold the original FD open while we recurse,
 	 to guarantee we'll get a new FD if we need it.  */
-      new = relocate_fd (new, min);
+      new = relocate_fd (new, minfd);
       close (fd);
       return new;
     }
@@ -1128,13 +1128,13 @@
 }
 
-/* Move the file descriptor FD so that its number is not less than MIN.
+/* Move the file descriptor FD so that its number is not less than MINFD.
    If the file descriptor is moved at all, the original is freed.  */
 int